from .halo_bg import HaloBg
from .halo_hpl import HaloHpl
from .halo_sys_params import HaloSysParams
from .windcube import WindCube, WindCubeFixed
from .wls70 import Wls70

__all__ = ["HaloHpl", "HaloBg", "HaloSysParams", "WindCube", "WindCubeFixed", "Wls70"]



import typer

app = typer.Typer()


@app.command()
def parse(file: str, merge: bool = False) -> None:
    """
    Parse raw hpl files into netCDF files
    """
    print(f"Hello {file}")


@app.command()
def stare() -> None:
    print("stare cmd")


@app.command()
def wind() -> None:
    print("wind cmd")


if __name__ == "__main__":
    app()
